==> qmpdclient-1.0.6.2.tar.gz: qmpdclient-1.0.6.2/src/stringlistview.h <==
/*
 * QMPDClient - An MPD client written in Qt 4.
 * Copyright (C) 2005-2006 Hvard Tautra Knutsen <havtknut@tihlde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifndef STRINGLISTVIEW_H
#define STRINGLISTVIEW_H

#include <QListView>
#include "mpdsonglist.h"

class MPD;
class StringListModel;

class StringListView : public QListView {
	Q_OBJECT

protected:
	bool m_midButtonDrag;
	MPD *m_mpd;
	QAction *m_playAction, *m_enqueueAction, *m_informationAction;
	QMenu *m_menu;
	QStringList m_strings;
	StringListModel *m_model;
	void contextMenuEvent(QContextMenuEvent *);
	void selectionChanged(const QItemSelection & = QItemSelection(), const QItemSelection & = QItemSelection());
	void startDrag(Qt::DropActions);
	void mouseMoveEvent(QMouseEvent *);
	void mousePressEvent(QMouseEvent *);
	void mouseReleaseEvent(QMouseEvent *);

	virtual MPDSongList getSelectedSongs() = 0;

public:
	StringListView(QWidget *);

protected slots:
	void activated(const QModelIndex &);
	void enqueue();
	void filter(const QString &);
	void information();
	void play();

signals:
	void filterChanged(QRegExp);
};
#endif

==> qmpdclient-1.0.7.tar.gz: qmpdclient-1.0.7/src/stringlistview.h <==
/*
 * QMPDClient - An MPD client written in Qt 4.
 * Copyright (C) 2005-2006 Hvard Tautra Knutsen <havtknut@tihlde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifndef STRINGLISTVIEW_H
#define STRINGLISTVIEW_H

#include <QListView>
#include "mpdsonglist.h"

class StringListView : public QListView {
	Q_OBJECT

protected:
	bool m_midButtonDrag;
	class MPD *m_mpd;
	QAction *m_playAction, *m_enqueueAction, *m_informationAction;
	QMenu *m_menu;
	QStringList m_strings;
	class StringListModel *m_model;
	void contextMenuEvent(QContextMenuEvent *);
	void selectionChanged(const QItemSelection & = QItemSelection(), const QItemSelection & = QItemSelection());
	void mouseMoveEvent(QMouseEvent *);
	void mousePressEvent(QMouseEvent *);
	void mouseReleaseEvent(QMouseEvent *);

public:
	StringListView(QWidget *);
	virtual MPDSongList getSelectedSongs() const = 0;

protected slots:
	void activated(const QModelIndex &);
	void enqueue();
	void filter(const QString &);
	void information();
	void play();

signals:
	void filterChanged(const QRegExp &);
};
#endif
